@@ -1,5 +1,7 @@
 import json
 import logging
+import os
+import re
 
 from time import sleep
 
@@ -8,6 +10,9 @@ import requests
 from django.conf import settings
 
 
+safe_characters = re.compile(r"[^\w\- ]+")
+
+
 def rws_language_code(language_code):
     """
     Returns the mapped RWS language code, if found in the LANGUAGE_CODE_MAP setting.
@@ -93,10 +98,13 @@ class ApiClient:
         if not self.is_authenticated:
             raise NotAuthenticated()
 
+        # Ensure the name doesn't include special characters
+        cleaned_name = safe_characters.sub("", name)
+
         source_language_code = rws_language_code(source_locale)
         body = json.dumps(
             {
-                "name": name,
+                "name": cleaned_name,
                 "dueBy": due_by,
                 "description": description,
                 "projectTemplate": {"id": template_id},
@@ -152,10 +160,24 @@ class ApiClient:
         if not self.is_authenticated:
             raise NotAuthenticated()
 
+        # Clean the filename, leaving the file extension alone
+        filename_sans_ext = ""
+        parts = filename.split(os.extsep)
+        if len(parts) > 1:
+            ext = parts.pop()
+            filename_sans_ext = os.extsep.join(parts)
+        else:
+            ext = ""
+
+        # Strip out special characters from the filename
+        cleaned_filename = (
+            safe_characters.sub("", filename_sans_ext) + f"{os.extsep}{ext}"
+        )
+
         body = {
             "properties": json.dumps(
                 {
-                    "name": filename,
+                    "name": cleaned_filename,
                     "role": "translatable",
                     "type": "native",
                     "language": rws_language_code(source_locale),
@@ -163,7 +185,7 @@ class ApiClient:
                 }
             )
         }
-        files = {"file": (filename, po_file, "text/plain")}
+        files = {"file": (cleaned_filename, po_file, "text/plain")}
         r = requests.post(
             f"{self.api_base}/projects/{project_id}/source-files",
             data=body,
